@@ -25,8 +25,8 @@ import oauthlib.oauth2
 from oauthlib.common import add_params_to_uri, to_unicode, urlencode
 from sanic.request import RequestParameters
 from sanic.response import redirect
-from spf import SanicPlugin
-from spf.plugin import PluginAssociated
+from sanic_plugin_toolkit import SanicPlugin
+from sanic_plugin_toolkit.plugin import PluginAssociated
 
 from .utils import to_bytes
 
@@ -129,9 +129,9 @@ class OAuthClient(SanicPlugin):
         for name, remote in self._lazy_load_apps.items():
             remote.oauth = assoc
             context.remote_apps[name] = remote
-
-        app.extensions = getattr(app, 'extensions', {})
-        app.extensions['oauthlib.client'] = self
+        app_ctx = app.ctx if hasattr(app, "ctx") else app
+        app_ctx.extensions = getattr(app_ctx, 'extensions', {})
+        app_ctx.extensions['oauthlib.client'] = self
 
 
 oauthclient = instance = OAuthClient()
