@@ -19,8 +19,8 @@ from oauthlib.oauth1 import WebApplicationServer as Server
 from oauthlib.oauth1.rfc5849 import errors
 from sanic.exceptions import Unauthorized
 from sanic.response import HTTPResponse, redirect
-from spf import SanicPlugin
-from spf.plugin import PluginAssociated
+from sanic_plugin_toolkit import SanicPlugin
+from sanic_plugin_toolkit.plugin import PluginAssociated
 
 from ..utils import create_response, extract_params
 
@@ -574,8 +574,9 @@ class OAuth1Provider(SanicPlugin):
         context._config = {k: v for k, v in app.config.items() if k.startswith("OAUTH1_")}
         context._before_request_funcs = []
         context._after_request_funcs = []
-        app.extensions = getattr(app, 'extensions', {})
-        app.extensions['oauthlib.provider.oauth1'] = self
+        app_ctx = app.ctx if hasattr(app, "ctx") else app
+        app_ctx.extensions = getattr(app_ctx, 'extensions', {})
+        app_ctx.extensions['oauthlib.provider.oauth1'] = self
 
     @classmethod
     async def confirm_authorization_request(cls, request, context, assoc):
@@ -584,7 +585,7 @@ class OAuth1Provider(SanicPlugin):
         shared_context = context.shared
         shared_request_context = shared_context.request[id(request)]
         # In oauth1, the only way for a user to add new items to the credentials
-        # list is to put them in the current spf shared_context or session
+        # list is to put them in the current sptk shared_context or session
         session = shared_request_context.get('session', None)
         uri, http_method, body, headers = extract_params(request)
         try:
