@@ -20,8 +20,8 @@ from oauthlib.common import add_params_to_uri
 from oauthlib.oauth2 import RequestValidator, Server
 from sanic import response
 from sanic.exceptions import Unauthorized
-from spf import SanicPlugin
-from spf.plugin import PluginAssociated
+from sanic_plugin_toolkit import SanicPlugin
+from sanic_plugin_toolkit.plugin import PluginAssociated
 
 from ..utils import create_response, extract_params, import_string
 
@@ -629,8 +629,9 @@ class OAuth2Provider(SanicPlugin):
         context._exception_handler = None
         context._invalid_response = None
         context._validator_class = validator_class
-        app.extensions = getattr(app, 'extensions', {})
-        app.extensions['oauthlib.provider.oauth2'] = self
+        app_ctx = app.ctx if hasattr(app, "ctx") else app
+        app_ctx.extensions = getattr(app_ctx, 'extensions', {})
+        app_ctx.extensions['oauthlib.provider.oauth2'] = self
 
     @classmethod
     def _on_exception(cls, context, error, redirect_content=None):
